@@ -7,9 +7,11 @@ An AI-powered intelligent mock data generation library that supports flexible ru
 from .core.rule import Rule, RuleType
 from .core.rule_combination import RuleCombination
 from .core.rule_package import RulePackage
+from .core.table_rule import TableRule, TableOutputFormat
 from .core.shadow_ai import ShadowAI
+from .utils.table_formatter import TableFormatter, TableTemplates
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 __author__ = "ShadowAI Team"
 __email__ = "team@shadowai.com"
 
@@ -19,4 +21,8 @@ __all__ = [
     "RuleType",
     "RulePackage",
     "RuleCombination",
+    "TableRule",
+    "TableOutputFormat",
+    "TableFormatter",
+    "TableTemplates",
 ]
