@@ -1,5 +1,5 @@
 """
-MockAI Built-in Rules Module
+ShadowAI Built-in Rules Module
 
 Provides commonly used predefined rules for direct user access.
 """
@@ -37,7 +37,7 @@ from .packages import (
 __all__ = [
     # Basic rules
     "email_rule",
-    "first_name_rule", 
+    "first_name_rule",
     "last_name_rule",
     "age_rule",
     "phone_rule",
@@ -52,15 +52,13 @@ __all__ = [
     "boolean_rule",
     "number_rule",
     "text_rule",
-    
     # Combinations
     "full_name_combination",
-    "full_address_combination", 
+    "full_address_combination",
     "datetime_combination",
-    
     # Packages
     "person_package",
     "company_package",
     "product_package",
     "user_package",
-] 
\ No newline at end of file
+]
